<template>
  <div class="intangible-asset">
    <div class="asset-top">
      <div class="top-content">
        <div class="item" v-for="(item, index) in statisticsList"
          :style="{ 'border-right': (index + 1) % 4 == 0 ? 'none' : '1px solid #E6F1FF', 'border-bottom': index > 3 ? 'none' : '1px solid #E6F1FF' }">
          <div>
            <div class="amount" :style="{ 'color': item.value < 10 ? '#E57E17 ' : '#0F2A4D' }">{{ item.value }}</div>
            <div class="label" :style="{ 'color': item.value < 10 ? '#E57E17 ' : '#7A8899' }">{{ item.label }}</div>
          </div>
        </div>
      </div>
    </div>
    <div class="asset-bottom">
      <div class="item">
        <PublicTitle :iconUrl="require('@/assets/img/publicTitle/icon-无形.png')" title="公司商标数量排名" />
        <div id="trademark-chart"></div>

      </div>
      <div class="item">
        <PublicTitle :iconUrl="require('@/assets/img/publicTitle/icon-无形.png')" title="公司专利数量排名" />
        <div id="patent-chart"></div>

      </div>
      <div class="item">
        <PublicTitle :iconUrl="require('@/assets/img/publicTitle/icon-无形.png')" title="公司著作权数量排名" />
        <div id="work-chart"></div>

      </div>
      <div class="item">
        <PublicTitle :iconUrl="require('@/assets/img/publicTitle/icon-无形.png')" title="公司非专利技术数量排名" />
        <div id="unpatent-chart"></div>

      </div>
    </div>
  </div>
</template>

<script>
import * as echarts from 'echarts'
import utils from '@/utils.js'
import PublicTitle from '@/components/PublicTitle/index'
export default {
  name: 'IntangibleAsset',
  props: {},
  components: {
    PublicTitle,
  },
  data() {
    return {
      statisticsList: [
        {
          label: '商标',
          value: 10
        }, {
          label: '到期商标',
          value: 1
        }, {
          label: '专利',
          value: 32
        }, {
          label: '到期专利',
          value: 3
        }, {
          label: '著作权',
          value: 10
        }, {
          label: '到期著作权',
          value: 1
        }, {
          label: '非专利技术',
          value: 23
        }, {
          label: '到期非专利技术',
          value: 2
        },
      ],
    }
  },
  created() {

  },
  mounted() {
    this.$nextTick(() => {
      this.initTrademark()
      this.initPatent()
      this.initWork()
      this.initUnpatent()
    })``

  },
  methods: {
    initTrademark() {
      let xData = ['鱼复', '新利富', '航投', '体投', '协同创新区', '云计算', '龙兴', '景观']
      let bookData = [32, 30, 28, 25, 22, 20, 1, 0]
      let chartDom = echarts.init(
        document.getElementById('trademark-chart')
      )
      let option = {
        tooltip: {
          trigger: 'axis',
          axisPointer: {
            // 坐标轴指示器，坐标轴触发有效
            type: 'shadow', // 默认为直线，可选为：'line' | 'shadow'
          },
        },
        grid: {
          left: '1%',
          top: '0',
          right: '0',
          bottom: '0',
          containLabel: true,
        },
        xAxis: [
          {
            show: false,
            type: 'value',
            name: '(单位:次)',
          },
        ],
        yAxis: [
          {
            data: xData,
            inverse: true,//反向
            axisLine: {
              show: false
            },
            axisTick: {
              show: false
            },
            axisLabel: {
              fontSize: 12,
              formatter: function (value, index) {
                // var sureInd = xData.map(item => item).indexOf(value) + 1
                var sureInd = index + 1
                console.log(sureInd)
                if (sureInd == 1) {
                  return '{a|' + sureInd + '}' + '{e|' + value + '}'
                }
                else if (sureInd == 2) {
                  return '{b|' + sureInd + '}' + '{e|' + value + '}'
                } else if (sureInd == 3) {
                  return '{c|' + sureInd + '}' + '{e|' + value + '}'
                } else {
                  return '{d|' + sureInd + '}' + '{e|' + value + '}'
                }
              },
              rich: {
                a: {
                  backgroundColor: "#FFE387",
                  fontWeight: 700,
                  color: '#000',
                  width: 18,
                  height: 18,
                  lineHeight: 18,
                  align: "center",
                  borderRadius: 9,
                },
                e: {
                  color: '#666666',
                  width: 50,
                  textAlign: 'right'
                },
                b: {
                  backgroundColor: "#D0E0EB",
                  fontWeight: 700,
                  color: '#000',
                  width: 18,
                  height: 18,
                  lineHeight: 18,
                  align: "center",
                  borderRadius: 9,
                },
                c: {
                  backgroundColor: "#F3BEAC",
                  fontWeight: 700,
                  color: '#000',
                  width: 18,
                  height: 18,
                  lineHeight: 18,
                  align: "center",
                  borderRadius: 9,
                },
                d: {
                  backgroundColor: "#fff",
                  fontWeight: 700,
                  color: '#000',
                  width: 18,
                  height: 18,
                  align: "center",
                  lineHeight: 18,
                  borderRadius: 9,
                },
              }
            }
          },
          {

            inverse: true,//反向
            position: 'right',//坐标轴位置，移至右边
            axisLine: {
              show: false
            },
            axisTick: {
              show: false
            },
            show: false,
            data: xData,
            axisLabel: {
              color: "#333",
              formatter: function (value, index) {
                if (value.length > 7) {
                  return value.slice(0, 6) + "..."
                } else {
                  return value
                }
              }
            }
          }
        ],
        series: [
          {
            type: 'bar',
            data: bookData,
            barWidth: '15',
            stack: 'user',
            label: {
              show: true, // 显示标签
              position: 'right',
              fontSize: 16,
              color: '#000',
              offset: [10, 2],
            },
            itemStyle: {
              color: {
                type: 'linear',
                x: 1,
                y: 0,
                x2: 0,
                y2: 0,
                colorStops: [
                  {
                    offset: 0,
                    color: '#198CFF', // 渐变起始颜色（绿色）
                  },
                  {
                    offset: 1,
                    color: 'rgba(25, 140, 255,0.2)', // 渐变结束颜色（深绿色）
                  },
                ],
              },
              borderRadius: [0, 3, 3, 0], // 设置圆角大小

            },
          },
        ],
      }
      chartDom.setOption(option)
      window.addEventListener('resize', () => {
        chartDom.resize()
      })
    },
    initPatent() {
      let xData = ['鱼复', '体投', '协同创新区', '新利富', '航投', '云计算', '龙兴', '景观']
      let bookData = [90, 80, 70, 60, 50, 40, 40, 30]
      let chartDom = echarts.init(
        document.getElementById('patent-chart')
      )
      let option = {
        tooltip: {
          trigger: 'axis',
          axisPointer: {
            // 坐标轴指示器，坐标轴触发有效
            type: 'shadow', // 默认为直线，可选为：'line' | 'shadow'
          },
        },
        grid: {
          left: '1%',
          top: '0',
          right: '0',
          bottom: '0',
          containLabel: true,
        },
        xAxis: [
          {
            show: false,
            type: 'value',
            name: '(单位:次)',
          },
        ],
        yAxis: [
          {
            data: xData,
            inverse: true,//反向
            axisLine: {
              show: false
            },
            axisTick: {
              show: false
            },
            axisLabel: {
              fontSize: 12,
              formatter: function (value, index) {
                // var sureInd = xData.map(item => item).indexOf(value) + 1
                var sureInd = index + 1
                console.log(sureInd)
                if (sureInd == 1) {
                  return '{a|' + sureInd + '}' + '{e|' + value + '}'
                }
                else if (sureInd == 2) {
                  return '{b|' + sureInd + '}' + '{e|' + value + '}'
                } else if (sureInd == 3) {
                  return '{c|' + sureInd + '}' + '{e|' + value + '}'
                } else {
                  return '{d|' + sureInd + '}' + '{e|' + value + '}'
                }
              },
              rich: {
                a: {
                  backgroundColor: "#FFE387",
                  fontWeight: 700,
                  color: '#000',
                  width: 18,
                  height: 18,
                  lineHeight: 18,
                  align: "center",
                  borderRadius: 9,
                },
                e: {
                  color: '#666666',
                  width: 50,
                  textAlign: 'right'
                },
                b: {
                  backgroundColor: "#D0E0EB",
                  fontWeight: 700,
                  color: '#000',
                  width: 18,
                  height: 18,
                  lineHeight: 18,
                  align: "center",
                  borderRadius: 9,
                },
                c: {
                  backgroundColor: "#F3BEAC",
                  fontWeight: 700,
                  color: '#000',
                  width: 18,
                  height: 18,
                  lineHeight: 18,
                  align: "center",
                  borderRadius: 9,
                },
                d: {
                  backgroundColor: "#fff",
                  fontWeight: 700,
                  color: '#000',
                  width: 18,
                  height: 18,
                  align: "center",
                  lineHeight: 18,
                  borderRadius: 9,
                },
              }
            }
          },
          {

            inverse: true,//反向
            position: 'right',//坐标轴位置，移至右边
            axisLine: {
              show: false
            },
            axisTick: {
              show: false
            },
            show: false,
            data: xData,
            axisLabel: {
              color: "#333",
              formatter: function (value, index) {
                if (value.length > 7) {
                  return value.slice(0, 6) + "..."
                } else {
                  return value
                }
              }
            }
          }
        ],
        series: [
          {
            type: 'bar',
            data: bookData,
            barWidth: '15',
            stack: 'user',
            label: {
              show: true, // 显示标签
              position: 'right',
              fontSize: 16,
              color: '#000',
              offset: [10, 2],
            },
            itemStyle: {
              color: {
                type: 'linear',
                x: 1,
                y: 0,
                x2: 0,
                y2: 0,
                colorStops: [
                  {
                    offset: 0,
                    color: '#198CFF', // 渐变起始颜色（绿色）
                  },
                  {
                    offset: 1,
                    color: 'rgba(25, 140, 255,0.2)', // 渐变结束颜色（深绿色）
                  },
                ],
              },
              borderRadius: [0, 3, 3, 0], // 设置圆角大小
            },
          },
        ],
      }
      chartDom.setOption(option)
      window.addEventListener('resize', () => {
        chartDom.resize()
      })
    },
    initWork() {
      let xData =  ['新利富', '航投', '云计算', '龙兴', '景观','鱼复', '体投', '协同创新区',]
      let bookData = [95, 90, 80, 77, 65, 44, 40,  20]
      let chartDom = echarts.init(
        document.getElementById('work-chart')
      )
      let option = {
        tooltip: {
          trigger: 'axis',
          axisPointer: {
            // 坐标轴指示器，坐标轴触发有效
            type: 'shadow', // 默认为直线，可选为：'line' | 'shadow'
          },
        },
        grid: {
          left: '1%',
          top: '0',
          right: '0',
          bottom: '0',
          containLabel: true,
        },
        xAxis: [
          {
            show: false,
            type: 'value',
            name: '(单位:次)',
          },
        ],
        yAxis: [
          {
            data: xData,
            inverse: true,//反向
            axisLine: {
              show: false
            },
            axisTick: {
              show: false
            },
            axisLabel: {
              fontSize: 12,
              formatter: function (value, index) {
                // var sureInd = xData.map(item => item).indexOf(value) + 1
                var sureInd = index + 1
                console.log(sureInd)
                if (sureInd == 1) {
                  return '{a|' + sureInd + '}' + '{e|' + value + '}'
                }
                else if (sureInd == 2) {
                  return '{b|' + sureInd + '}' + '{e|' + value + '}'
                } else if (sureInd == 3) {
                  return '{c|' + sureInd + '}' + '{e|' + value + '}'
                } else {
                  return '{d|' + sureInd + '}' + '{e|' + value + '}'
                }
              },
              rich: {
                a: {
                  backgroundColor: "#FFE387",
                  fontWeight: 700,
                  color: '#000',
                  width: 18,
                  height: 18,
                  lineHeight: 18,
                  align: "center",
                  borderRadius: 9,
                },
                e: {
                  color: '#666666',
                  width: 50,
                  textAlign: 'right'
                },
                b: {
                  backgroundColor: "#D0E0EB",
                  fontWeight: 700,
                  color: '#000',
                  width: 18,
                  height: 18,
                  lineHeight: 18,
                  align: "center",
                  borderRadius: 9,
                },
                c: {
                  backgroundColor: "#F3BEAC",
                  fontWeight: 700,
                  color: '#000',
                  width: 18,
                  height: 18,
                  lineHeight: 18,
                  align: "center",
                  borderRadius: 9,
                },
                d: {
                  backgroundColor: "#fff",
                  fontWeight: 700,
                  color: '#000',
                  width: 18,
                  height: 18,
                  align: "center",
                  lineHeight: 18,
                  borderRadius: 9,
                },
              }
            }
          },
          {

            inverse: true,//反向
            position: 'right',//坐标轴位置，移至右边
            axisLine: {
              show: false
            },
            axisTick: {
              show: false
            },
            show: false,
            data: xData,
            axisLabel: {
              color: "#333",
              formatter: function (value, index) {
                if (value.length > 7) {
                  return value.slice(0, 6) + "..."
                } else {
                  return value
                }
              }
            }
          }
        ],
        series: [
          {
            type: 'bar',
            data: bookData,
            barWidth: '15',
            stack: 'user',
            label: {
              show: true, // 显示标签
              position: 'right',
              fontSize: 16,
              color: '#000',
              offset: [10, 2],
            },
            itemStyle: {
              color: {
                type: 'linear',
                x: 1,
                y: 0,
                x2: 0,
                y2: 0,
                colorStops: [
                  {
                    offset: 0,
                    color: '#198CFF', // 渐变起始颜色（绿色）
                  },
                  {
                    offset: 1,
                    color: 'rgba(25, 140, 255,0.2)', // 渐变结束颜色（深绿色）
                  },
                ],
              },
              borderRadius: [0, 3, 3, 0], // 设置圆角大小

            },
          },
        ],
      }
      chartDom.setOption(option)
      window.addEventListener('resize', () => {
        chartDom.resize()
      })
    },
    initUnpatent() {
      let xData =[ '龙兴', '景观','鱼复','新利富', '航投', '云计算', '体投', '协同创新区',]
      
      let bookData = [90, 80, 70, 60, 50, 40, 30, 20]
      let chartDom = echarts.init(
        document.getElementById('unpatent-chart')
      )
      let option = {
        tooltip: {
          trigger: 'axis',
          axisPointer: {
            // 坐标轴指示器，坐标轴触发有效
            type: 'shadow', // 默认为直线，可选为：'line' | 'shadow'
          },
        },
        grid: {
          left: '1%',
          top: '0',
          right: '0',
          bottom: '0',
          containLabel: true,
        },
        xAxis: [
          {
            show: false,
            type: 'value',
            name: '(单位:次)',
          },
        ],
        yAxis: [
          {
            data: xData,
            inverse: true,//反向
            axisLine: {
              show: false
            },
            axisTick: {
              show: false
            },
            axisLabel: {
              fontSize: 12,
              formatter: function (value, index) {
                // var sureInd = xData.map(item => item).indexOf(value) + 1
                var sureInd = index + 1
                console.log(sureInd)
                if (sureInd == 1) {
                  return '{a|' + sureInd + '}' + '{e|' + value + '}'
                }
                else if (sureInd == 2) {
                  return '{b|' + sureInd + '}' + '{e|' + value + '}'
                } else if (sureInd == 3) {
                  return '{c|' + sureInd + '}' + '{e|' + value + '}'
                } else {
                  return '{d|' + sureInd + '}' + '{e|' + value + '}'
                }
              },
              rich: {
                a: {
                  backgroundColor: "#FFE387",
                  fontWeight: 700,
                  color: '#000',
                  width: 18,
                  height: 18,
                  lineHeight: 18,
                  align: "center",
                  borderRadius: 9,
                },
                e: {
                  color: '#666666',
                  width: 50,
                  textAlign: 'right'
                },
                b: {
                  backgroundColor: "#D0E0EB",
                  fontWeight: 700,
                  color: '#000',
                  width: 18,
                  height: 18,
                  lineHeight: 18,
                  align: "center",
                  borderRadius: 9,
                },
                c: {
                  backgroundColor: "#F3BEAC",
                  fontWeight: 700,
                  color: '#000',
                  width: 18,
                  height: 18,
                  lineHeight: 18,
                  align: "center",
                  borderRadius: 9,
                },
                d: {
                  backgroundColor: "#fff",
                  fontWeight: 700,
                  color: '#000',
                  width: 18,
                  height: 18,
                  align: "center",
                  lineHeight: 18,
                  borderRadius: 9,
                },
              }
            }
          },
          {

            inverse: true,//反向
            position: 'right',//坐标轴位置，移至右边
            axisLine: {
              show: false
            },
            axisTick: {
              show: false
            },
            show: false,
            data: xData,
            axisLabel: {
              color: "#333",
              formatter: function (value, index) {
                if (value.length > 7) {
                  return value.slice(0, 6) + "..."
                } else {
                  return value
                }
              }
            }
          }
        ],
        series: [
          {
            type: 'bar',
            data: bookData,
            barWidth: '15',
            stack: 'user',
            label: {
              show: true, // 显示标签
              position: 'right',
              fontSize: 16,
              color: '#000',
              offset: [10, 2],
            },
            itemStyle: {
              color: {
                type: 'linear',
                x: 1,
                y: 0,
                x2: 0,
                y2: 0,
                colorStops: [
                  {
                    offset: 0,
                    color: '#198CFF', // 渐变起始颜色（绿色）
                  },
                  {
                    offset: 1,
                    color: 'rgba(25, 140, 255,0.2)', // 渐变结束颜色（深绿色）
                  },
                ],
              },
              borderRadius: [0, 3, 3, 0], // 设置圆角大小

            },
          },
        ],
      }
      chartDom.setOption(option)
      window.addEventListener('resize', () => {
        chartDom.resize()
      })
    },
  }
}
</script>

<style lang="scss" scoped>
.intangible-asset {
  width: 100%;
  height: 100%;
  padding: 16px 24px;
  box-sizing: border-box;
  display: flex;
  flex-direction: column;
  justify-content: space-between;

  .asset-top {
    width: 100%;
    height: 30%;
    padding: 16px;
    box-sizing: border-box;
    background: #FFFFFF;
    box-shadow: 4px 4px 10px 0px rgba(53, 152, 220, 0.1);
    border-radius: 16px 16px 16px 16px;
    opacity: 1;

    .top-content {
      width: 100%;
      height: 100%;
      border-radius: 8px 8px 8px 8px;
      opacity: 1;
      border: 1px solid #E6F1FF;
      display: flex;
      flex-wrap: wrap;

      .item {
        width: 25%;
        height: 50%;
        box-sizing: border-box;
        border-right: 1px solid #E6F1FF;
        border-bottom: 1px solid #E6F1FF;
        text-align: center;
        display: flex;
        flex-direction: column;
        justify-content: space-evenly;

        .amount {
          font-size: 26px;
          font-family: Microsoft YaHei, Microsoft YaHei;
          font-weight: 700;
          line-height: 34px;
        }

        .label {
          font-size: 16px;
          font-family: Microsoft YaHei, Microsoft YaHei;
          font-weight: 400;
          line-height: 21px;
        }
      }
    }
  }

  .asset-bottom {
    width: 100%;
    height: calc(70% - 16px);
    display: flex;
    justify-content: space-between;

    .item {
      width: calc(25% - 12px);
      height: 100%;
      padding: 16px;
      box-sizing: border-box;
      background: #FFFFFF;
      box-shadow: 4px 4px 10px 0px rgba(53, 152, 220, 0.1);
      border-radius: 16px 16px 16px 16px;
      opacity: 1;

      #trademark-chart {
        width: 100%;
        height: calc(100% - 30px);
      }

      #patent-chart {
        width: 100%;
        height: calc(100% - 30px);
      }

      #work-chart {
        width: 100%;
        height: calc(100% - 30px);
      }

      #unpatent-chart {
        width: 100%;
        height: calc(100% - 30px);
      }
    }
  }
}</style>
